quote

package
v0.6.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2022 License: Apache-1.1 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Route

func Route(router RouteOut) (string, string, quickfix.MessageRoute)

Route returns the beginstring, message type, and MessageRoute for this Message type.

Types

type Quote added in v0.4.0

type Quote struct {
	fix40.Header
	*quickfix.Body
	fix40.Trailer
	Message *quickfix.Message
}

Quote is the fix40 Quote type, MsgType = S.

func FromMessage added in v0.4.0

func FromMessage(m *quickfix.Message) Quote

FromMessage creates a Quote from a quickfix.Message instance.

func New added in v0.2.0

func New(quoteid field.QuoteIDField, symbol field.SymbolField, bidpx field.BidPxField) (m Quote)

New returns a Quote initialized with the required fields for Quote.

func (Quote) GetBidPx added in v0.4.0

func (m Quote) GetBidPx() (v decimal.Decimal, err quickfix.MessageRejectError)

GetBidPx gets BidPx, Tag 132.

func (Quote) GetBidSize added in v0.4.0

func (m Quote) GetBidSize() (v decimal.Decimal, err quickfix.MessageRejectError)

GetBidSize gets BidSize, Tag 134.

func (Quote) GetIDSource added in v0.4.0

func (m Quote) GetIDSource() (v enum.IDSource, err quickfix.MessageRejectError)

GetIDSource gets IDSource, Tag 22.

func (Quote) GetIssuer added in v0.4.0

func (m Quote) GetIssuer() (v string, err quickfix.MessageRejectError)

GetIssuer gets Issuer, Tag 106.

func (Quote) GetOfferPx added in v0.4.0

func (m Quote) GetOfferPx() (v decimal.Decimal, err quickfix.MessageRejectError)

GetOfferPx gets OfferPx, Tag 133.

func (Quote) GetOfferSize added in v0.4.0

func (m Quote) GetOfferSize() (v decimal.Decimal, err quickfix.MessageRejectError)

GetOfferSize gets OfferSize, Tag 135.

func (Quote) GetQuoteID added in v0.4.0

func (m Quote) GetQuoteID() (v string, err quickfix.MessageRejectError)

GetQuoteID gets QuoteID, Tag 117.

func (Quote) GetQuoteReqID added in v0.4.0

func (m Quote) GetQuoteReqID() (v string, err quickfix.MessageRejectError)

GetQuoteReqID gets QuoteReqID, Tag 131.

func (Quote) GetSecurityDesc added in v0.4.0

func (m Quote) GetSecurityDesc() (v string, err quickfix.MessageRejectError)

GetSecurityDesc gets SecurityDesc, Tag 107.

func (Quote) GetSecurityID added in v0.4.0

func (m Quote) GetSecurityID() (v string, err quickfix.MessageRejectError)

GetSecurityID gets SecurityID, Tag 48.

func (Quote) GetSymbol added in v0.4.0

func (m Quote) GetSymbol() (v string, err quickfix.MessageRejectError)

GetSymbol gets Symbol, Tag 55.

func (Quote) GetSymbolSfx added in v0.4.0

func (m Quote) GetSymbolSfx() (v enum.SymbolSfx, err quickfix.MessageRejectError)

GetSymbolSfx gets SymbolSfx, Tag 65.

func (Quote) GetValidUntilTime added in v0.4.0

func (m Quote) GetValidUntilTime() (v time.Time, err quickfix.MessageRejectError)

GetValidUntilTime gets ValidUntilTime, Tag 62.

func (Quote) HasBidPx added in v0.4.0

func (m Quote) HasBidPx() bool

HasBidPx returns true if BidPx is present, Tag 132.

func (Quote) HasBidSize added in v0.4.0

func (m Quote) HasBidSize() bool

HasBidSize returns true if BidSize is present, Tag 134.

func (Quote) HasIDSource added in v0.4.0

func (m Quote) HasIDSource() bool

HasIDSource returns true if IDSource is present, Tag 22.

func (Quote) HasIssuer added in v0.4.0

func (m Quote) HasIssuer() bool

HasIssuer returns true if Issuer is present, Tag 106.

func (Quote) HasOfferPx added in v0.4.0

func (m Quote) HasOfferPx() bool

HasOfferPx returns true if OfferPx is present, Tag 133.

func (Quote) HasOfferSize added in v0.4.0

func (m Quote) HasOfferSize() bool

HasOfferSize returns true if OfferSize is present, Tag 135.

func (Quote) HasQuoteID added in v0.4.0

func (m Quote) HasQuoteID() bool

HasQuoteID returns true if QuoteID is present, Tag 117.

func (Quote) HasQuoteReqID added in v0.4.0

func (m Quote) HasQuoteReqID() bool

HasQuoteReqID returns true if QuoteReqID is present, Tag 131.

func (Quote) HasSecurityDesc added in v0.4.0

func (m Quote) HasSecurityDesc() bool

HasSecurityDesc returns true if SecurityDesc is present, Tag 107.

func (Quote) HasSecurityID added in v0.4.0

func (m Quote) HasSecurityID() bool

HasSecurityID returns true if SecurityID is present, Tag 48.

func (Quote) HasSymbol added in v0.4.0

func (m Quote) HasSymbol() bool

HasSymbol returns true if Symbol is present, Tag 55.

func (Quote) HasSymbolSfx added in v0.4.0

func (m Quote) HasSymbolSfx() bool

HasSymbolSfx returns true if SymbolSfx is present, Tag 65.

func (Quote) HasValidUntilTime added in v0.4.0

func (m Quote) HasValidUntilTime() bool

HasValidUntilTime returns true if ValidUntilTime is present, Tag 62.

func (Quote) SetBidPx added in v0.4.0

func (m Quote) SetBidPx(value decimal.Decimal, scale int32)

SetBidPx sets BidPx, Tag 132.

func (Quote) SetBidSize added in v0.4.0

func (m Quote) SetBidSize(value decimal.Decimal, scale int32)

SetBidSize sets BidSize, Tag 134.

func (Quote) SetIDSource added in v0.4.0

func (m Quote) SetIDSource(v enum.IDSource)

SetIDSource sets IDSource, Tag 22.

func (Quote) SetIssuer added in v0.4.0

func (m Quote) SetIssuer(v string)

SetIssuer sets Issuer, Tag 106.

func (Quote) SetOfferPx added in v0.4.0

func (m Quote) SetOfferPx(value decimal.Decimal, scale int32)

SetOfferPx sets OfferPx, Tag 133.

func (Quote) SetOfferSize added in v0.4.0

func (m Quote) SetOfferSize(value decimal.Decimal, scale int32)

SetOfferSize sets OfferSize, Tag 135.

func (Quote) SetQuoteID added in v0.4.0

func (m Quote) SetQuoteID(v string)

SetQuoteID sets QuoteID, Tag 117.

func (Quote) SetQuoteReqID added in v0.4.0

func (m Quote) SetQuoteReqID(v string)

SetQuoteReqID sets QuoteReqID, Tag 131.

func (Quote) SetSecurityDesc added in v0.4.0

func (m Quote) SetSecurityDesc(v string)

SetSecurityDesc sets SecurityDesc, Tag 107.

func (Quote) SetSecurityID added in v0.4.0

func (m Quote) SetSecurityID(v string)

SetSecurityID sets SecurityID, Tag 48.

func (Quote) SetSymbol added in v0.4.0

func (m Quote) SetSymbol(v string)

SetSymbol sets Symbol, Tag 55.

func (Quote) SetSymbolSfx added in v0.4.0

func (m Quote) SetSymbolSfx(v enum.SymbolSfx)

SetSymbolSfx sets SymbolSfx, Tag 65.

func (Quote) SetValidUntilTime added in v0.4.0

func (m Quote) SetValidUntilTime(v time.Time)

SetValidUntilTime sets ValidUntilTime, Tag 62.

func (Quote) ToMessage added in v0.4.0

func (m Quote) ToMessage() *quickfix.Message

ToMessage returns a quickfix.Message instance.

type RouteOut

type RouteOut func(msg Quote, sessionID quickfix.SessionID) quickfix.MessageRejectError

A RouteOut is the callback type that should be implemented for routing Message.

Jump to