settlementinstructions

package
v0.6.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2022 License: Apache-1.1 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Route

func Route(router RouteOut) (string, string, quickfix.MessageRoute)

Route returns the beginstring, message type, and MessageRoute for this Message type.

Types

type NoPartyIDs added in v0.4.0

type NoPartyIDs struct {
	*quickfix.Group
}

NoPartyIDs is a repeating group element, Tag 453.

func (NoPartyIDs) GetPartyID added in v0.4.0

func (m NoPartyIDs) GetPartyID() (v string, err quickfix.MessageRejectError)

GetPartyID gets PartyID, Tag 448.

func (NoPartyIDs) GetPartyIDSource added in v0.4.0

func (m NoPartyIDs) GetPartyIDSource() (v enum.PartyIDSource, err quickfix.MessageRejectError)

GetPartyIDSource gets PartyIDSource, Tag 447.

func (NoPartyIDs) GetPartyRole added in v0.4.0

func (m NoPartyIDs) GetPartyRole() (v enum.PartyRole, err quickfix.MessageRejectError)

GetPartyRole gets PartyRole, Tag 452.

func (NoPartyIDs) GetPartySubID added in v0.4.0

func (m NoPartyIDs) GetPartySubID() (v string, err quickfix.MessageRejectError)

GetPartySubID gets PartySubID, Tag 523.

func (NoPartyIDs) HasPartyID added in v0.4.0

func (m NoPartyIDs) HasPartyID() bool

HasPartyID returns true if PartyID is present, Tag 448.

func (NoPartyIDs) HasPartyIDSource added in v0.4.0

func (m NoPartyIDs) HasPartyIDSource() bool

HasPartyIDSource returns true if PartyIDSource is present, Tag 447.

func (NoPartyIDs) HasPartyRole added in v0.4.0

func (m NoPartyIDs) HasPartyRole() bool

HasPartyRole returns true if PartyRole is present, Tag 452.

func (NoPartyIDs) HasPartySubID added in v0.4.0

func (m NoPartyIDs) HasPartySubID() bool

HasPartySubID returns true if PartySubID is present, Tag 523.

func (NoPartyIDs) SetPartyID added in v0.4.0

func (m NoPartyIDs) SetPartyID(v string)

SetPartyID sets PartyID, Tag 448.

func (NoPartyIDs) SetPartyIDSource added in v0.4.0

func (m NoPartyIDs) SetPartyIDSource(v enum.PartyIDSource)

SetPartyIDSource sets PartyIDSource, Tag 447.

func (NoPartyIDs) SetPartyRole added in v0.4.0

func (m NoPartyIDs) SetPartyRole(v enum.PartyRole)

SetPartyRole sets PartyRole, Tag 452.

func (NoPartyIDs) SetPartySubID added in v0.4.0

func (m NoPartyIDs) SetPartySubID(v string)

SetPartySubID sets PartySubID, Tag 523.

type NoPartyIDsRepeatingGroup added in v0.4.0

type NoPartyIDsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoPartyIDsRepeatingGroup is a repeating group, Tag 453.

func NewNoPartyIDsRepeatingGroup added in v0.4.0

func NewNoPartyIDsRepeatingGroup() NoPartyIDsRepeatingGroup

NewNoPartyIDsRepeatingGroup returns an initialized, NoPartyIDsRepeatingGroup.

func (NoPartyIDsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoPartyIDs to this group.

func (NoPartyIDsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoPartyIDs in the NoPartyIDsRepeatinGroup.

type RouteOut

A RouteOut is the callback type that should be implemented for routing Message.

type SettlementInstructions added in v0.4.0

type SettlementInstructions struct {
	fix43.Header
	*quickfix.Body
	fix43.Trailer
	Message *quickfix.Message
}

SettlementInstructions is the fix43 SettlementInstructions type, MsgType = T.

func FromMessage added in v0.4.0

func FromMessage(m *quickfix.Message) SettlementInstructions

FromMessage creates a SettlementInstructions from a quickfix.Message instance.

func New added in v0.2.0

func New(settlinstid field.SettlInstIDField, settlinsttranstype field.SettlInstTransTypeField, settlinstrefid field.SettlInstRefIDField, settlinstmode field.SettlInstModeField, settlinstsource field.SettlInstSourceField, allocaccount field.AllocAccountField, transacttime field.TransactTimeField) (m SettlementInstructions)

New returns a SettlementInstructions initialized with the required fields for SettlementInstructions.

func (SettlementInstructions) GetAllocAccount added in v0.4.0

func (m SettlementInstructions) GetAllocAccount() (v string, err quickfix.MessageRejectError)

GetAllocAccount gets AllocAccount, Tag 79.

func (SettlementInstructions) GetAllocID added in v0.4.0

func (m SettlementInstructions) GetAllocID() (v string, err quickfix.MessageRejectError)

GetAllocID gets AllocID, Tag 70.

func (SettlementInstructions) GetCardExpDate added in v0.4.0

func (m SettlementInstructions) GetCardExpDate() (v string, err quickfix.MessageRejectError)

GetCardExpDate gets CardExpDate, Tag 490.

func (SettlementInstructions) GetCardHolderName added in v0.4.0

func (m SettlementInstructions) GetCardHolderName() (v string, err quickfix.MessageRejectError)

GetCardHolderName gets CardHolderName, Tag 488.

func (SettlementInstructions) GetCardIssNo added in v0.4.0

func (m SettlementInstructions) GetCardIssNo() (v string, err quickfix.MessageRejectError)

GetCardIssNo gets CardIssNo, Tag 491.

func (SettlementInstructions) GetCardNumber added in v0.4.0

func (m SettlementInstructions) GetCardNumber() (v string, err quickfix.MessageRejectError)

GetCardNumber gets CardNumber, Tag 489.

func (SettlementInstructions) GetCardStartDate added in v0.4.0

func (m SettlementInstructions) GetCardStartDate() (v string, err quickfix.MessageRejectError)

GetCardStartDate gets CardStartDate, Tag 503.

func (SettlementInstructions) GetCashSettlAgentAcctName added in v0.4.0

func (m SettlementInstructions) GetCashSettlAgentAcctName() (v string, err quickfix.MessageRejectError)

GetCashSettlAgentAcctName gets CashSettlAgentAcctName, Tag 185.

func (SettlementInstructions) GetCashSettlAgentAcctNum added in v0.4.0

func (m SettlementInstructions) GetCashSettlAgentAcctNum() (v string, err quickfix.MessageRejectError)

GetCashSettlAgentAcctNum gets CashSettlAgentAcctNum, Tag 184.

func (SettlementInstructions) GetCashSettlAgentCode added in v0.4.0

func (m SettlementInstructions) GetCashSettlAgentCode() (v string, err quickfix.MessageRejectError)

GetCashSettlAgentCode gets CashSettlAgentCode, Tag 183.

func (SettlementInstructions) GetCashSettlAgentContactName added in v0.4.0

func (m SettlementInstructions) GetCashSettlAgentContactName() (v string, err quickfix.MessageRejectError)

GetCashSettlAgentContactName gets CashSettlAgentContactName, Tag 186.

func (SettlementInstructions) GetCashSettlAgentContactPhone added in v0.4.0

func (m SettlementInstructions) GetCashSettlAgentContactPhone() (v string, err quickfix.MessageRejectError)

GetCashSettlAgentContactPhone gets CashSettlAgentContactPhone, Tag 187.

func (SettlementInstructions) GetCashSettlAgentName added in v0.4.0

func (m SettlementInstructions) GetCashSettlAgentName() (v string, err quickfix.MessageRejectError)

GetCashSettlAgentName gets CashSettlAgentName, Tag 182.

func (SettlementInstructions) GetClOrdID added in v0.4.0

func (m SettlementInstructions) GetClOrdID() (v string, err quickfix.MessageRejectError)

GetClOrdID gets ClOrdID, Tag 11.

func (SettlementInstructions) GetEffectiveTime added in v0.4.0

func (m SettlementInstructions) GetEffectiveTime() (v time.Time, err quickfix.MessageRejectError)

GetEffectiveTime gets EffectiveTime, Tag 168.

func (SettlementInstructions) GetIndividualAllocID added in v0.4.0

func (m SettlementInstructions) GetIndividualAllocID() (v string, err quickfix.MessageRejectError)

GetIndividualAllocID gets IndividualAllocID, Tag 467.

func (SettlementInstructions) GetLastMkt added in v0.4.0

func (m SettlementInstructions) GetLastMkt() (v string, err quickfix.MessageRejectError)

GetLastMkt gets LastMkt, Tag 30.

func (SettlementInstructions) GetNoPartyIDs added in v0.4.0

GetNoPartyIDs gets NoPartyIDs, Tag 453.

func (SettlementInstructions) GetPaymentDate added in v0.4.0

func (m SettlementInstructions) GetPaymentDate() (v string, err quickfix.MessageRejectError)

GetPaymentDate gets PaymentDate, Tag 504.

func (SettlementInstructions) GetPaymentMethod added in v0.4.0

GetPaymentMethod gets PaymentMethod, Tag 492.

func (SettlementInstructions) GetPaymentRef added in v0.4.0

func (m SettlementInstructions) GetPaymentRef() (v string, err quickfix.MessageRejectError)

GetPaymentRef gets PaymentRef, Tag 476.

func (SettlementInstructions) GetPaymentRemitterID added in v0.4.0

func (m SettlementInstructions) GetPaymentRemitterID() (v string, err quickfix.MessageRejectError)

GetPaymentRemitterID gets PaymentRemitterID, Tag 505.

func (SettlementInstructions) GetSecuritySettlAgentAcctName added in v0.4.0

func (m SettlementInstructions) GetSecuritySettlAgentAcctName() (v string, err quickfix.MessageRejectError)

GetSecuritySettlAgentAcctName gets SecuritySettlAgentAcctName, Tag 179.

func (SettlementInstructions) GetSecuritySettlAgentAcctNum added in v0.4.0

func (m SettlementInstructions) GetSecuritySettlAgentAcctNum() (v string, err quickfix.MessageRejectError)

GetSecuritySettlAgentAcctNum gets SecuritySettlAgentAcctNum, Tag 178.

func (SettlementInstructions) GetSecuritySettlAgentCode added in v0.4.0

func (m SettlementInstructions) GetSecuritySettlAgentCode() (v string, err quickfix.MessageRejectError)

GetSecuritySettlAgentCode gets SecuritySettlAgentCode, Tag 177.

func (SettlementInstructions) GetSecuritySettlAgentContactName added in v0.4.0

func (m SettlementInstructions) GetSecuritySettlAgentContactName() (v string, err quickfix.MessageRejectError)

GetSecuritySettlAgentContactName gets SecuritySettlAgentContactName, Tag 180.

func (SettlementInstructions) GetSecuritySettlAgentContactPhone added in v0.4.0

func (m SettlementInstructions) GetSecuritySettlAgentContactPhone() (v string, err quickfix.MessageRejectError)

GetSecuritySettlAgentContactPhone gets SecuritySettlAgentContactPhone, Tag 181.

func (SettlementInstructions) GetSecuritySettlAgentName added in v0.4.0

func (m SettlementInstructions) GetSecuritySettlAgentName() (v string, err quickfix.MessageRejectError)

GetSecuritySettlAgentName gets SecuritySettlAgentName, Tag 176.

func (SettlementInstructions) GetSecurityType added in v0.4.0

GetSecurityType gets SecurityType, Tag 167.

func (SettlementInstructions) GetSettlBrkrCode added in v0.4.0

func (m SettlementInstructions) GetSettlBrkrCode() (v string, err quickfix.MessageRejectError)

GetSettlBrkrCode gets SettlBrkrCode, Tag 174.

func (SettlementInstructions) GetSettlDeliveryType added in v0.4.0

func (m SettlementInstructions) GetSettlDeliveryType() (v enum.SettlDeliveryType, err quickfix.MessageRejectError)

GetSettlDeliveryType gets SettlDeliveryType, Tag 172.

func (SettlementInstructions) GetSettlDepositoryCode added in v0.4.0

func (m SettlementInstructions) GetSettlDepositoryCode() (v string, err quickfix.MessageRejectError)

GetSettlDepositoryCode gets SettlDepositoryCode, Tag 173.

func (SettlementInstructions) GetSettlInstCode added in v0.4.0

func (m SettlementInstructions) GetSettlInstCode() (v string, err quickfix.MessageRejectError)

GetSettlInstCode gets SettlInstCode, Tag 175.

func (SettlementInstructions) GetSettlInstID added in v0.4.0

func (m SettlementInstructions) GetSettlInstID() (v string, err quickfix.MessageRejectError)

GetSettlInstID gets SettlInstID, Tag 162.

func (SettlementInstructions) GetSettlInstMode added in v0.4.0

GetSettlInstMode gets SettlInstMode, Tag 160.

func (SettlementInstructions) GetSettlInstRefID added in v0.4.0

func (m SettlementInstructions) GetSettlInstRefID() (v string, err quickfix.MessageRejectError)

GetSettlInstRefID gets SettlInstRefID, Tag 214.

func (SettlementInstructions) GetSettlInstSource added in v0.4.0

func (m SettlementInstructions) GetSettlInstSource() (v enum.SettlInstSource, err quickfix.MessageRejectError)

GetSettlInstSource gets SettlInstSource, Tag 165.

func (SettlementInstructions) GetSettlInstTransType added in v0.4.0

func (m SettlementInstructions) GetSettlInstTransType() (v enum.SettlInstTransType, err quickfix.MessageRejectError)

GetSettlInstTransType gets SettlInstTransType, Tag 163.

func (SettlementInstructions) GetSide added in v0.4.0

GetSide gets Side, Tag 54.

func (SettlementInstructions) GetStandInstDbID added in v0.4.0

func (m SettlementInstructions) GetStandInstDbID() (v string, err quickfix.MessageRejectError)

GetStandInstDbID gets StandInstDbID, Tag 171.

func (SettlementInstructions) GetStandInstDbName added in v0.4.0

func (m SettlementInstructions) GetStandInstDbName() (v string, err quickfix.MessageRejectError)

GetStandInstDbName gets StandInstDbName, Tag 170.

func (SettlementInstructions) GetStandInstDbType added in v0.4.0

func (m SettlementInstructions) GetStandInstDbType() (v enum.StandInstDbType, err quickfix.MessageRejectError)

GetStandInstDbType gets StandInstDbType, Tag 169.

func (SettlementInstructions) GetTradeDate added in v0.4.0

func (m SettlementInstructions) GetTradeDate() (v string, err quickfix.MessageRejectError)

GetTradeDate gets TradeDate, Tag 75.

func (SettlementInstructions) GetTradingSessionID added in v0.4.0

func (m SettlementInstructions) GetTradingSessionID() (v enum.TradingSessionID, err quickfix.MessageRejectError)

GetTradingSessionID gets TradingSessionID, Tag 336.

func (SettlementInstructions) GetTradingSessionSubID added in v0.4.0

func (m SettlementInstructions) GetTradingSessionSubID() (v enum.TradingSessionSubID, err quickfix.MessageRejectError)

GetTradingSessionSubID gets TradingSessionSubID, Tag 625.

func (SettlementInstructions) GetTransactTime added in v0.4.0

func (m SettlementInstructions) GetTransactTime() (v time.Time, err quickfix.MessageRejectError)

GetTransactTime gets TransactTime, Tag 60.

func (SettlementInstructions) HasAllocAccount added in v0.4.0

func (m SettlementInstructions) HasAllocAccount() bool

HasAllocAccount returns true if AllocAccount is present, Tag 79.

func (SettlementInstructions) HasAllocID added in v0.4.0

func (m SettlementInstructions) HasAllocID() bool

HasAllocID returns true if AllocID is present, Tag 70.

func (SettlementInstructions) HasCardExpDate added in v0.4.0

func (m SettlementInstructions) HasCardExpDate() bool

HasCardExpDate returns true if CardExpDate is present, Tag 490.

func (SettlementInstructions) HasCardHolderName added in v0.4.0

func (m SettlementInstructions) HasCardHolderName() bool

HasCardHolderName returns true if CardHolderName is present, Tag 488.

func (SettlementInstructions) HasCardIssNo added in v0.4.0

func (m SettlementInstructions) HasCardIssNo() bool

HasCardIssNo returns true if CardIssNo is present, Tag 491.

func (SettlementInstructions) HasCardNumber added in v0.4.0

func (m SettlementInstructions) HasCardNumber() bool

HasCardNumber returns true if CardNumber is present, Tag 489.

func (SettlementInstructions) HasCardStartDate added in v0.4.0

func (m SettlementInstructions) HasCardStartDate() bool

HasCardStartDate returns true if CardStartDate is present, Tag 503.

func (SettlementInstructions) HasCashSettlAgentAcctName added in v0.4.0

func (m SettlementInstructions) HasCashSettlAgentAcctName() bool

HasCashSettlAgentAcctName returns true if CashSettlAgentAcctName is present, Tag 185.

func (SettlementInstructions) HasCashSettlAgentAcctNum added in v0.4.0

func (m SettlementInstructions) HasCashSettlAgentAcctNum() bool

HasCashSettlAgentAcctNum returns true if CashSettlAgentAcctNum is present, Tag 184.

func (SettlementInstructions) HasCashSettlAgentCode added in v0.4.0

func (m SettlementInstructions) HasCashSettlAgentCode() bool

HasCashSettlAgentCode returns true if CashSettlAgentCode is present, Tag 183.

func (SettlementInstructions) HasCashSettlAgentContactName added in v0.4.0

func (m SettlementInstructions) HasCashSettlAgentContactName() bool

HasCashSettlAgentContactName returns true if CashSettlAgentContactName is present, Tag 186.

func (SettlementInstructions) HasCashSettlAgentContactPhone added in v0.4.0

func (m SettlementInstructions) HasCashSettlAgentContactPhone() bool

HasCashSettlAgentContactPhone returns true if CashSettlAgentContactPhone is present, Tag 187.

func (SettlementInstructions) HasCashSettlAgentName added in v0.4.0

func (m SettlementInstructions) HasCashSettlAgentName() bool

HasCashSettlAgentName returns true if CashSettlAgentName is present, Tag 182.

func (SettlementInstructions) HasClOrdID added in v0.4.0

func (m SettlementInstructions) HasClOrdID() bool

HasClOrdID returns true if ClOrdID is present, Tag 11.

func (SettlementInstructions) HasEffectiveTime added in v0.4.0

func (m SettlementInstructions) HasEffectiveTime() bool

HasEffectiveTime returns true if EffectiveTime is present, Tag 168.

func (SettlementInstructions) HasIndividualAllocID added in v0.4.0

func (m SettlementInstructions) HasIndividualAllocID() bool

HasIndividualAllocID returns true if IndividualAllocID is present, Tag 467.

func (SettlementInstructions) HasLastMkt added in v0.4.0

func (m SettlementInstructions) HasLastMkt() bool

HasLastMkt returns true if LastMkt is present, Tag 30.

func (SettlementInstructions) HasNoPartyIDs added in v0.4.0

func (m SettlementInstructions) HasNoPartyIDs() bool

HasNoPartyIDs returns true if NoPartyIDs is present, Tag 453.

func (SettlementInstructions) HasPaymentDate added in v0.4.0

func (m SettlementInstructions) HasPaymentDate() bool

HasPaymentDate returns true if PaymentDate is present, Tag 504.

func (SettlementInstructions) HasPaymentMethod added in v0.4.0

func (m SettlementInstructions) HasPaymentMethod() bool

HasPaymentMethod returns true if PaymentMethod is present, Tag 492.

func (SettlementInstructions) HasPaymentRef added in v0.4.0

func (m SettlementInstructions) HasPaymentRef() bool

HasPaymentRef returns true if PaymentRef is present, Tag 476.

func (SettlementInstructions) HasPaymentRemitterID added in v0.4.0

func (m SettlementInstructions) HasPaymentRemitterID() bool

HasPaymentRemitterID returns true if PaymentRemitterID is present, Tag 505.

func (SettlementInstructions) HasSecuritySettlAgentAcctName added in v0.4.0

func (m SettlementInstructions) HasSecuritySettlAgentAcctName() bool

HasSecuritySettlAgentAcctName returns true if SecuritySettlAgentAcctName is present, Tag 179.

func (SettlementInstructions) HasSecuritySettlAgentAcctNum added in v0.4.0

func (m SettlementInstructions) HasSecuritySettlAgentAcctNum() bool

HasSecuritySettlAgentAcctNum returns true if SecuritySettlAgentAcctNum is present, Tag 178.

func (SettlementInstructions) HasSecuritySettlAgentCode added in v0.4.0

func (m SettlementInstructions) HasSecuritySettlAgentCode() bool

HasSecuritySettlAgentCode returns true if SecuritySettlAgentCode is present, Tag 177.

func (SettlementInstructions) HasSecuritySettlAgentContactName added in v0.4.0

func (m SettlementInstructions) HasSecuritySettlAgentContactName() bool

HasSecuritySettlAgentContactName returns true if SecuritySettlAgentContactName is present, Tag 180.

func (SettlementInstructions) HasSecuritySettlAgentContactPhone added in v0.4.0

func (m SettlementInstructions) HasSecuritySettlAgentContactPhone() bool

HasSecuritySettlAgentContactPhone returns true if SecuritySettlAgentContactPhone is present, Tag 181.

func (SettlementInstructions) HasSecuritySettlAgentName added in v0.4.0

func (m SettlementInstructions) HasSecuritySettlAgentName() bool

HasSecuritySettlAgentName returns true if SecuritySettlAgentName is present, Tag 176.

func (SettlementInstructions) HasSecurityType added in v0.4.0

func (m SettlementInstructions) HasSecurityType() bool

HasSecurityType returns true if SecurityType is present, Tag 167.

func (SettlementInstructions) HasSettlBrkrCode added in v0.4.0

func (m SettlementInstructions) HasSettlBrkrCode() bool

HasSettlBrkrCode returns true if SettlBrkrCode is present, Tag 174.

func (SettlementInstructions) HasSettlDeliveryType added in v0.4.0

func (m SettlementInstructions) HasSettlDeliveryType() bool

HasSettlDeliveryType returns true if SettlDeliveryType is present, Tag 172.

func (SettlementInstructions) HasSettlDepositoryCode added in v0.4.0

func (m SettlementInstructions) HasSettlDepositoryCode() bool

HasSettlDepositoryCode returns true if SettlDepositoryCode is present, Tag 173.

func (SettlementInstructions) HasSettlInstCode added in v0.4.0

func (m SettlementInstructions) HasSettlInstCode() bool

HasSettlInstCode returns true if SettlInstCode is present, Tag 175.

func (SettlementInstructions) HasSettlInstID added in v0.4.0

func (m SettlementInstructions) HasSettlInstID() bool

HasSettlInstID returns true if SettlInstID is present, Tag 162.

func (SettlementInstructions) HasSettlInstMode added in v0.4.0

func (m SettlementInstructions) HasSettlInstMode() bool

HasSettlInstMode returns true if SettlInstMode is present, Tag 160.

func (SettlementInstructions) HasSettlInstRefID added in v0.4.0

func (m SettlementInstructions) HasSettlInstRefID() bool

HasSettlInstRefID returns true if SettlInstRefID is present, Tag 214.

func (SettlementInstructions) HasSettlInstSource added in v0.4.0

func (m SettlementInstructions) HasSettlInstSource() bool

HasSettlInstSource returns true if SettlInstSource is present, Tag 165.

func (SettlementInstructions) HasSettlInstTransType added in v0.4.0

func (m SettlementInstructions) HasSettlInstTransType() bool

HasSettlInstTransType returns true if SettlInstTransType is present, Tag 163.

func (SettlementInstructions) HasSide added in v0.4.0

func (m SettlementInstructions) HasSide() bool

HasSide returns true if Side is present, Tag 54.

func (SettlementInstructions) HasStandInstDbID added in v0.4.0

func (m SettlementInstructions) HasStandInstDbID() bool

HasStandInstDbID returns true if StandInstDbID is present, Tag 171.

func (SettlementInstructions) HasStandInstDbName added in v0.4.0

func (m SettlementInstructions) HasStandInstDbName() bool

HasStandInstDbName returns true if StandInstDbName is present, Tag 170.

func (SettlementInstructions) HasStandInstDbType added in v0.4.0

func (m SettlementInstructions) HasStandInstDbType() bool

HasStandInstDbType returns true if StandInstDbType is present, Tag 169.

func (SettlementInstructions) HasTradeDate added in v0.4.0

func (m SettlementInstructions) HasTradeDate() bool

HasTradeDate returns true if TradeDate is present, Tag 75.

func (SettlementInstructions) HasTradingSessionID added in v0.4.0

func (m SettlementInstructions) HasTradingSessionID() bool

HasTradingSessionID returns true if TradingSessionID is present, Tag 336.

func (SettlementInstructions) HasTradingSessionSubID added in v0.4.0

func (m SettlementInstructions) HasTradingSessionSubID() bool

HasTradingSessionSubID returns true if TradingSessionSubID is present, Tag 625.

func (SettlementInstructions) HasTransactTime added in v0.4.0

func (m SettlementInstructions) HasTransactTime() bool

HasTransactTime returns true if TransactTime is present, Tag 60.

func (SettlementInstructions) SetAllocAccount added in v0.4.0

func (m SettlementInstructions) SetAllocAccount(v string)

SetAllocAccount sets AllocAccount, Tag 79.

func (SettlementInstructions) SetAllocID added in v0.4.0

func (m SettlementInstructions) SetAllocID(v string)

SetAllocID sets AllocID, Tag 70.

func (SettlementInstructions) SetCardExpDate added in v0.4.0

func (m SettlementInstructions) SetCardExpDate(v string)

SetCardExpDate sets CardExpDate, Tag 490.

func (SettlementInstructions) SetCardHolderName added in v0.4.0

func (m SettlementInstructions) SetCardHolderName(v string)

SetCardHolderName sets CardHolderName, Tag 488.

func (SettlementInstructions) SetCardIssNo added in v0.4.0

func (m SettlementInstructions) SetCardIssNo(v string)

SetCardIssNo sets CardIssNo, Tag 491.

func (SettlementInstructions) SetCardNumber added in v0.4.0

func (m SettlementInstructions) SetCardNumber(v string)

SetCardNumber sets CardNumber, Tag 489.

func (SettlementInstructions) SetCardStartDate added in v0.4.0

func (m SettlementInstructions) SetCardStartDate(v string)

SetCardStartDate sets CardStartDate, Tag 503.

func (SettlementInstructions) SetCashSettlAgentAcctName added in v0.4.0

func (m SettlementInstructions) SetCashSettlAgentAcctName(v string)

SetCashSettlAgentAcctName sets CashSettlAgentAcctName, Tag 185.

func (SettlementInstructions) SetCashSettlAgentAcctNum added in v0.4.0

func (m SettlementInstructions) SetCashSettlAgentAcctNum(v string)

SetCashSettlAgentAcctNum sets CashSettlAgentAcctNum, Tag 184.

func (SettlementInstructions) SetCashSettlAgentCode added in v0.4.0

func (m SettlementInstructions) SetCashSettlAgentCode(v string)

SetCashSettlAgentCode sets CashSettlAgentCode, Tag 183.

func (SettlementInstructions) SetCashSettlAgentContactName added in v0.4.0

func (m SettlementInstructions) SetCashSettlAgentContactName(v string)

SetCashSettlAgentContactName sets CashSettlAgentContactName, Tag 186.

func (SettlementInstructions) SetCashSettlAgentContactPhone added in v0.4.0

func (m SettlementInstructions) SetCashSettlAgentContactPhone(v string)

SetCashSettlAgentContactPhone sets CashSettlAgentContactPhone, Tag 187.

func (SettlementInstructions) SetCashSettlAgentName added in v0.4.0

func (m SettlementInstructions) SetCashSettlAgentName(v string)

SetCashSettlAgentName sets CashSettlAgentName, Tag 182.

func (SettlementInstructions) SetClOrdID added in v0.4.0

func (m SettlementInstructions) SetClOrdID(v string)

SetClOrdID sets ClOrdID, Tag 11.

func (SettlementInstructions) SetEffectiveTime added in v0.4.0

func (m SettlementInstructions) SetEffectiveTime(v time.Time)

SetEffectiveTime sets EffectiveTime, Tag 168.

func (SettlementInstructions) SetIndividualAllocID added in v0.4.0

func (m SettlementInstructions) SetIndividualAllocID(v string)

SetIndividualAllocID sets IndividualAllocID, Tag 467.

func (SettlementInstructions) SetLastMkt added in v0.4.0

func (m SettlementInstructions) SetLastMkt(v string)

SetLastMkt sets LastMkt, Tag 30.

func (SettlementInstructions) SetNoPartyIDs added in v0.4.0

SetNoPartyIDs sets NoPartyIDs, Tag 453.

func (SettlementInstructions) SetPaymentDate added in v0.4.0

func (m SettlementInstructions) SetPaymentDate(v string)

SetPaymentDate sets PaymentDate, Tag 504.

func (SettlementInstructions) SetPaymentMethod added in v0.4.0

func (m SettlementInstructions) SetPaymentMethod(v enum.PaymentMethod)

SetPaymentMethod sets PaymentMethod, Tag 492.

func (SettlementInstructions) SetPaymentRef added in v0.4.0

func (m SettlementInstructions) SetPaymentRef(v string)

SetPaymentRef sets PaymentRef, Tag 476.

func (SettlementInstructions) SetPaymentRemitterID added in v0.4.0

func (m SettlementInstructions) SetPaymentRemitterID(v string)

SetPaymentRemitterID sets PaymentRemitterID, Tag 505.

func (SettlementInstructions) SetSecuritySettlAgentAcctName added in v0.4.0

func (m SettlementInstructions) SetSecuritySettlAgentAcctName(v string)

SetSecuritySettlAgentAcctName sets SecuritySettlAgentAcctName, Tag 179.

func (SettlementInstructions) SetSecuritySettlAgentAcctNum added in v0.4.0

func (m SettlementInstructions) SetSecuritySettlAgentAcctNum(v string)

SetSecuritySettlAgentAcctNum sets SecuritySettlAgentAcctNum, Tag 178.

func (SettlementInstructions) SetSecuritySettlAgentCode added in v0.4.0

func (m SettlementInstructions) SetSecuritySettlAgentCode(v string)

SetSecuritySettlAgentCode sets SecuritySettlAgentCode, Tag 177.

func (SettlementInstructions) SetSecuritySettlAgentContactName added in v0.4.0

func (m SettlementInstructions) SetSecuritySettlAgentContactName(v string)

SetSecuritySettlAgentContactName sets SecuritySettlAgentContactName, Tag 180.

func (SettlementInstructions) SetSecuritySettlAgentContactPhone added in v0.4.0

func (m SettlementInstructions) SetSecuritySettlAgentContactPhone(v string)

SetSecuritySettlAgentContactPhone sets SecuritySettlAgentContactPhone, Tag 181.

func (SettlementInstructions) SetSecuritySettlAgentName added in v0.4.0

func (m SettlementInstructions) SetSecuritySettlAgentName(v string)

SetSecuritySettlAgentName sets SecuritySettlAgentName, Tag 176.

func (SettlementInstructions) SetSecurityType added in v0.4.0

func (m SettlementInstructions) SetSecurityType(v enum.SecurityType)

SetSecurityType sets SecurityType, Tag 167.

func (SettlementInstructions) SetSettlBrkrCode added in v0.4.0

func (m SettlementInstructions) SetSettlBrkrCode(v string)

SetSettlBrkrCode sets SettlBrkrCode, Tag 174.

func (SettlementInstructions) SetSettlDeliveryType added in v0.4.0

func (m SettlementInstructions) SetSettlDeliveryType(v enum.SettlDeliveryType)

SetSettlDeliveryType sets SettlDeliveryType, Tag 172.

func (SettlementInstructions) SetSettlDepositoryCode added in v0.4.0

func (m SettlementInstructions) SetSettlDepositoryCode(v string)

SetSettlDepositoryCode sets SettlDepositoryCode, Tag 173.

func (SettlementInstructions) SetSettlInstCode added in v0.4.0

func (m SettlementInstructions) SetSettlInstCode(v string)

SetSettlInstCode sets SettlInstCode, Tag 175.

func (SettlementInstructions) SetSettlInstID added in v0.4.0

func (m SettlementInstructions) SetSettlInstID(v string)

SetSettlInstID sets SettlInstID, Tag 162.

func (SettlementInstructions) SetSettlInstMode added in v0.4.0

func (m SettlementInstructions) SetSettlInstMode(v enum.SettlInstMode)

SetSettlInstMode sets SettlInstMode, Tag 160.

func (SettlementInstructions) SetSettlInstRefID added in v0.4.0

func (m SettlementInstructions) SetSettlInstRefID(v string)

SetSettlInstRefID sets SettlInstRefID, Tag 214.

func (SettlementInstructions) SetSettlInstSource added in v0.4.0

func (m SettlementInstructions) SetSettlInstSource(v enum.SettlInstSource)

SetSettlInstSource sets SettlInstSource, Tag 165.

func (SettlementInstructions) SetSettlInstTransType added in v0.4.0

func (m SettlementInstructions) SetSettlInstTransType(v enum.SettlInstTransType)

SetSettlInstTransType sets SettlInstTransType, Tag 163.

func (SettlementInstructions) SetSide added in v0.4.0

func (m SettlementInstructions) SetSide(v enum.Side)

SetSide sets Side, Tag 54.

func (SettlementInstructions) SetStandInstDbID added in v0.4.0

func (m SettlementInstructions) SetStandInstDbID(v string)

SetStandInstDbID sets StandInstDbID, Tag 171.

func (SettlementInstructions) SetStandInstDbName added in v0.4.0

func (m SettlementInstructions) SetStandInstDbName(v string)

SetStandInstDbName sets StandInstDbName, Tag 170.

func (SettlementInstructions) SetStandInstDbType added in v0.4.0

func (m SettlementInstructions) SetStandInstDbType(v enum.StandInstDbType)

SetStandInstDbType sets StandInstDbType, Tag 169.

func (SettlementInstructions) SetTradeDate added in v0.4.0

func (m SettlementInstructions) SetTradeDate(v string)

SetTradeDate sets TradeDate, Tag 75.

func (SettlementInstructions) SetTradingSessionID added in v0.4.0

func (m SettlementInstructions) SetTradingSessionID(v enum.TradingSessionID)

SetTradingSessionID sets TradingSessionID, Tag 336.

func (SettlementInstructions) SetTradingSessionSubID added in v0.4.0

func (m SettlementInstructions) SetTradingSessionSubID(v enum.TradingSessionSubID)

SetTradingSessionSubID sets TradingSessionSubID, Tag 625.

func (SettlementInstructions) SetTransactTime added in v0.4.0

func (m SettlementInstructions) SetTransactTime(v time.Time)

SetTransactTime sets TransactTime, Tag 60.

func (SettlementInstructions) ToMessage added in v0.4.0

func (m SettlementInstructions) ToMessage() *quickfix.Message

ToMessage returns a quickfix.Message instance.

Jump to