allocationreportack

package
v0.6.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2022 License: Apache-1.1 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Route

func Route(router RouteOut) (string, string, quickfix.MessageRoute)

Route returns the beginstring, message type, and MessageRoute for this Message type.

Types

type AllocationReportAck added in v0.4.0

type AllocationReportAck struct {
	fixt11.Header
	*quickfix.Body
	fixt11.Trailer
	Message *quickfix.Message
}

AllocationReportAck is the fix50sp2 AllocationReportAck type, MsgType = AT.

func FromMessage added in v0.4.0

func FromMessage(m *quickfix.Message) AllocationReportAck

FromMessage creates a AllocationReportAck from a quickfix.Message instance.

func New added in v0.2.0

func New(allocreportid field.AllocReportIDField) (m AllocationReportAck)

New returns a AllocationReportAck initialized with the required fields for AllocationReportAck.

func (AllocationReportAck) GetAllocID added in v0.4.0

func (m AllocationReportAck) GetAllocID() (v string, err quickfix.MessageRejectError)

GetAllocID gets AllocID, Tag 70.

func (AllocationReportAck) GetAllocIntermedReqType added in v0.4.0

func (m AllocationReportAck) GetAllocIntermedReqType() (v enum.AllocIntermedReqType, err quickfix.MessageRejectError)

GetAllocIntermedReqType gets AllocIntermedReqType, Tag 808.

func (AllocationReportAck) GetAllocRejCode added in v0.4.0

func (m AllocationReportAck) GetAllocRejCode() (v enum.AllocRejCode, err quickfix.MessageRejectError)

GetAllocRejCode gets AllocRejCode, Tag 88.

func (AllocationReportAck) GetAllocReportID added in v0.4.0

func (m AllocationReportAck) GetAllocReportID() (v string, err quickfix.MessageRejectError)

GetAllocReportID gets AllocReportID, Tag 755.

func (AllocationReportAck) GetAllocReportType added in v0.4.0

func (m AllocationReportAck) GetAllocReportType() (v enum.AllocReportType, err quickfix.MessageRejectError)

GetAllocReportType gets AllocReportType, Tag 794.

func (AllocationReportAck) GetAllocStatus added in v0.4.0

func (m AllocationReportAck) GetAllocStatus() (v enum.AllocStatus, err quickfix.MessageRejectError)

GetAllocStatus gets AllocStatus, Tag 87.

func (AllocationReportAck) GetAllocTransType added in v0.4.0

func (m AllocationReportAck) GetAllocTransType() (v enum.AllocTransType, err quickfix.MessageRejectError)

GetAllocTransType gets AllocTransType, Tag 71.

func (AllocationReportAck) GetAvgPxIndicator added in v0.4.0

func (m AllocationReportAck) GetAvgPxIndicator() (v enum.AvgPxIndicator, err quickfix.MessageRejectError)

GetAvgPxIndicator gets AvgPxIndicator, Tag 819.

func (AllocationReportAck) GetClearingBusinessDate added in v0.4.0

func (m AllocationReportAck) GetClearingBusinessDate() (v string, err quickfix.MessageRejectError)

GetClearingBusinessDate gets ClearingBusinessDate, Tag 715.

func (AllocationReportAck) GetEncodedText added in v0.4.0

func (m AllocationReportAck) GetEncodedText() (v string, err quickfix.MessageRejectError)

GetEncodedText gets EncodedText, Tag 355.

func (AllocationReportAck) GetEncodedTextLen added in v0.4.0

func (m AllocationReportAck) GetEncodedTextLen() (v int, err quickfix.MessageRejectError)

GetEncodedTextLen gets EncodedTextLen, Tag 354.

func (AllocationReportAck) GetMatchStatus added in v0.4.0

func (m AllocationReportAck) GetMatchStatus() (v enum.MatchStatus, err quickfix.MessageRejectError)

GetMatchStatus gets MatchStatus, Tag 573.

func (AllocationReportAck) GetNoAllocs added in v0.4.0

GetNoAllocs gets NoAllocs, Tag 78.

func (AllocationReportAck) GetNoPartyIDs added in v0.4.0

GetNoPartyIDs gets NoPartyIDs, Tag 453.

func (AllocationReportAck) GetProduct added in v0.4.0

GetProduct gets Product, Tag 460.

func (AllocationReportAck) GetQuantity added in v0.4.0

GetQuantity gets Quantity, Tag 53.

func (AllocationReportAck) GetSecondaryAllocID added in v0.4.0

func (m AllocationReportAck) GetSecondaryAllocID() (v string, err quickfix.MessageRejectError)

GetSecondaryAllocID gets SecondaryAllocID, Tag 793.

func (AllocationReportAck) GetSecurityType added in v0.4.0

func (m AllocationReportAck) GetSecurityType() (v enum.SecurityType, err quickfix.MessageRejectError)

GetSecurityType gets SecurityType, Tag 167.

func (AllocationReportAck) GetText added in v0.4.0

GetText gets Text, Tag 58.

func (AllocationReportAck) GetTradeDate added in v0.4.0

func (m AllocationReportAck) GetTradeDate() (v string, err quickfix.MessageRejectError)

GetTradeDate gets TradeDate, Tag 75.

func (AllocationReportAck) GetTransactTime added in v0.4.0

func (m AllocationReportAck) GetTransactTime() (v time.Time, err quickfix.MessageRejectError)

GetTransactTime gets TransactTime, Tag 60.

func (AllocationReportAck) HasAllocID added in v0.4.0

func (m AllocationReportAck) HasAllocID() bool

HasAllocID returns true if AllocID is present, Tag 70.

func (AllocationReportAck) HasAllocIntermedReqType added in v0.4.0

func (m AllocationReportAck) HasAllocIntermedReqType() bool

HasAllocIntermedReqType returns true if AllocIntermedReqType is present, Tag 808.

func (AllocationReportAck) HasAllocRejCode added in v0.4.0

func (m AllocationReportAck) HasAllocRejCode() bool

HasAllocRejCode returns true if AllocRejCode is present, Tag 88.

func (AllocationReportAck) HasAllocReportID added in v0.4.0

func (m AllocationReportAck) HasAllocReportID() bool

HasAllocReportID returns true if AllocReportID is present, Tag 755.

func (AllocationReportAck) HasAllocReportType added in v0.4.0

func (m AllocationReportAck) HasAllocReportType() bool

HasAllocReportType returns true if AllocReportType is present, Tag 794.

func (AllocationReportAck) HasAllocStatus added in v0.4.0

func (m AllocationReportAck) HasAllocStatus() bool

HasAllocStatus returns true if AllocStatus is present, Tag 87.

func (AllocationReportAck) HasAllocTransType added in v0.4.0

func (m AllocationReportAck) HasAllocTransType() bool

HasAllocTransType returns true if AllocTransType is present, Tag 71.

func (AllocationReportAck) HasAvgPxIndicator added in v0.4.0

func (m AllocationReportAck) HasAvgPxIndicator() bool

HasAvgPxIndicator returns true if AvgPxIndicator is present, Tag 819.

func (AllocationReportAck) HasClearingBusinessDate added in v0.4.0

func (m AllocationReportAck) HasClearingBusinessDate() bool

HasClearingBusinessDate returns true if ClearingBusinessDate is present, Tag 715.

func (AllocationReportAck) HasEncodedText added in v0.4.0

func (m AllocationReportAck) HasEncodedText() bool

HasEncodedText returns true if EncodedText is present, Tag 355.

func (AllocationReportAck) HasEncodedTextLen added in v0.4.0

func (m AllocationReportAck) HasEncodedTextLen() bool

HasEncodedTextLen returns true if EncodedTextLen is present, Tag 354.

func (AllocationReportAck) HasMatchStatus added in v0.4.0

func (m AllocationReportAck) HasMatchStatus() bool

HasMatchStatus returns true if MatchStatus is present, Tag 573.

func (AllocationReportAck) HasNoAllocs added in v0.4.0

func (m AllocationReportAck) HasNoAllocs() bool

HasNoAllocs returns true if NoAllocs is present, Tag 78.

func (AllocationReportAck) HasNoPartyIDs added in v0.4.0

func (m AllocationReportAck) HasNoPartyIDs() bool

HasNoPartyIDs returns true if NoPartyIDs is present, Tag 453.

func (AllocationReportAck) HasProduct added in v0.4.0

func (m AllocationReportAck) HasProduct() bool

HasProduct returns true if Product is present, Tag 460.

func (AllocationReportAck) HasQuantity added in v0.4.0

func (m AllocationReportAck) HasQuantity() bool

HasQuantity returns true if Quantity is present, Tag 53.

func (AllocationReportAck) HasSecondaryAllocID added in v0.4.0

func (m AllocationReportAck) HasSecondaryAllocID() bool

HasSecondaryAllocID returns true if SecondaryAllocID is present, Tag 793.

func (AllocationReportAck) HasSecurityType added in v0.4.0

func (m AllocationReportAck) HasSecurityType() bool

HasSecurityType returns true if SecurityType is present, Tag 167.

func (AllocationReportAck) HasText added in v0.4.0

func (m AllocationReportAck) HasText() bool

HasText returns true if Text is present, Tag 58.

func (AllocationReportAck) HasTradeDate added in v0.4.0

func (m AllocationReportAck) HasTradeDate() bool

HasTradeDate returns true if TradeDate is present, Tag 75.

func (AllocationReportAck) HasTransactTime added in v0.4.0

func (m AllocationReportAck) HasTransactTime() bool

HasTransactTime returns true if TransactTime is present, Tag 60.

func (AllocationReportAck) SetAllocID added in v0.4.0

func (m AllocationReportAck) SetAllocID(v string)

SetAllocID sets AllocID, Tag 70.

func (AllocationReportAck) SetAllocIntermedReqType added in v0.4.0

func (m AllocationReportAck) SetAllocIntermedReqType(v enum.AllocIntermedReqType)

SetAllocIntermedReqType sets AllocIntermedReqType, Tag 808.

func (AllocationReportAck) SetAllocRejCode added in v0.4.0

func (m AllocationReportAck) SetAllocRejCode(v enum.AllocRejCode)

SetAllocRejCode sets AllocRejCode, Tag 88.

func (AllocationReportAck) SetAllocReportID added in v0.4.0

func (m AllocationReportAck) SetAllocReportID(v string)

SetAllocReportID sets AllocReportID, Tag 755.

func (AllocationReportAck) SetAllocReportType added in v0.4.0

func (m AllocationReportAck) SetAllocReportType(v enum.AllocReportType)

SetAllocReportType sets AllocReportType, Tag 794.

func (AllocationReportAck) SetAllocStatus added in v0.4.0

func (m AllocationReportAck) SetAllocStatus(v enum.AllocStatus)

SetAllocStatus sets AllocStatus, Tag 87.

func (AllocationReportAck) SetAllocTransType added in v0.4.0

func (m AllocationReportAck) SetAllocTransType(v enum.AllocTransType)

SetAllocTransType sets AllocTransType, Tag 71.

func (AllocationReportAck) SetAvgPxIndicator added in v0.4.0

func (m AllocationReportAck) SetAvgPxIndicator(v enum.AvgPxIndicator)

SetAvgPxIndicator sets AvgPxIndicator, Tag 819.

func (AllocationReportAck) SetClearingBusinessDate added in v0.4.0

func (m AllocationReportAck) SetClearingBusinessDate(v string)

SetClearingBusinessDate sets ClearingBusinessDate, Tag 715.

func (AllocationReportAck) SetEncodedText added in v0.4.0

func (m AllocationReportAck) SetEncodedText(v string)

SetEncodedText sets EncodedText, Tag 355.

func (AllocationReportAck) SetEncodedTextLen added in v0.4.0

func (m AllocationReportAck) SetEncodedTextLen(v int)

SetEncodedTextLen sets EncodedTextLen, Tag 354.

func (AllocationReportAck) SetMatchStatus added in v0.4.0

func (m AllocationReportAck) SetMatchStatus(v enum.MatchStatus)

SetMatchStatus sets MatchStatus, Tag 573.

func (AllocationReportAck) SetNoAllocs added in v0.4.0

SetNoAllocs sets NoAllocs, Tag 78.

func (AllocationReportAck) SetNoPartyIDs added in v0.4.0

func (m AllocationReportAck) SetNoPartyIDs(f NoPartyIDsRepeatingGroup)

SetNoPartyIDs sets NoPartyIDs, Tag 453.

func (AllocationReportAck) SetProduct added in v0.4.0

func (m AllocationReportAck) SetProduct(v enum.Product)

SetProduct sets Product, Tag 460.

func (AllocationReportAck) SetQuantity added in v0.4.0

func (m AllocationReportAck) SetQuantity(value decimal.Decimal, scale int32)

SetQuantity sets Quantity, Tag 53.

func (AllocationReportAck) SetSecondaryAllocID added in v0.4.0

func (m AllocationReportAck) SetSecondaryAllocID(v string)

SetSecondaryAllocID sets SecondaryAllocID, Tag 793.

func (AllocationReportAck) SetSecurityType added in v0.4.0

func (m AllocationReportAck) SetSecurityType(v enum.SecurityType)

SetSecurityType sets SecurityType, Tag 167.

func (AllocationReportAck) SetText added in v0.4.0

func (m AllocationReportAck) SetText(v string)

SetText sets Text, Tag 58.

func (AllocationReportAck) SetTradeDate added in v0.4.0

func (m AllocationReportAck) SetTradeDate(v string)

SetTradeDate sets TradeDate, Tag 75.

func (AllocationReportAck) SetTransactTime added in v0.4.0

func (m AllocationReportAck) SetTransactTime(v time.Time)

SetTransactTime sets TransactTime, Tag 60.

func (AllocationReportAck) ToMessage added in v0.4.0

func (m AllocationReportAck) ToMessage() *quickfix.Message

ToMessage returns a quickfix.Message instance.

type NoAllocs added in v0.4.0

type NoAllocs struct {
	*quickfix.Group
}

NoAllocs is a repeating group element, Tag 78.

func (NoAllocs) GetAllocAccount added in v0.4.0

func (m NoAllocs) GetAllocAccount() (v string, err quickfix.MessageRejectError)

GetAllocAccount gets AllocAccount, Tag 79.

func (NoAllocs) GetAllocAcctIDSource added in v0.4.0

func (m NoAllocs) GetAllocAcctIDSource() (v int, err quickfix.MessageRejectError)

GetAllocAcctIDSource gets AllocAcctIDSource, Tag 661.

func (NoAllocs) GetAllocCustomerCapacity added in v0.4.0

func (m NoAllocs) GetAllocCustomerCapacity() (v string, err quickfix.MessageRejectError)

GetAllocCustomerCapacity gets AllocCustomerCapacity, Tag 993.

func (NoAllocs) GetAllocPositionEffect added in v0.4.0

func (m NoAllocs) GetAllocPositionEffect() (v enum.AllocPositionEffect, err quickfix.MessageRejectError)

GetAllocPositionEffect gets AllocPositionEffect, Tag 1047.

func (NoAllocs) GetAllocPrice added in v0.4.0

func (m NoAllocs) GetAllocPrice() (v decimal.Decimal, err quickfix.MessageRejectError)

GetAllocPrice gets AllocPrice, Tag 366.

func (NoAllocs) GetAllocQty added in v0.4.0

func (m NoAllocs) GetAllocQty() (v decimal.Decimal, err quickfix.MessageRejectError)

GetAllocQty gets AllocQty, Tag 80.

func (NoAllocs) GetAllocText added in v0.4.0

func (m NoAllocs) GetAllocText() (v string, err quickfix.MessageRejectError)

GetAllocText gets AllocText, Tag 161.

func (NoAllocs) GetEncodedAllocText added in v0.4.0

func (m NoAllocs) GetEncodedAllocText() (v string, err quickfix.MessageRejectError)

GetEncodedAllocText gets EncodedAllocText, Tag 361.

func (NoAllocs) GetEncodedAllocTextLen added in v0.4.0

func (m NoAllocs) GetEncodedAllocTextLen() (v int, err quickfix.MessageRejectError)

GetEncodedAllocTextLen gets EncodedAllocTextLen, Tag 360.

func (NoAllocs) GetIndividualAllocID added in v0.4.0

func (m NoAllocs) GetIndividualAllocID() (v string, err quickfix.MessageRejectError)

GetIndividualAllocID gets IndividualAllocID, Tag 467.

func (NoAllocs) GetIndividualAllocRejCode added in v0.4.0

func (m NoAllocs) GetIndividualAllocRejCode() (v int, err quickfix.MessageRejectError)

GetIndividualAllocRejCode gets IndividualAllocRejCode, Tag 776.

func (NoAllocs) GetIndividualAllocType added in v0.4.0

func (m NoAllocs) GetIndividualAllocType() (v enum.IndividualAllocType, err quickfix.MessageRejectError)

GetIndividualAllocType gets IndividualAllocType, Tag 992.

func (NoAllocs) GetNoNestedPartyIDs added in v0.4.0

GetNoNestedPartyIDs gets NoNestedPartyIDs, Tag 539.

func (NoAllocs) GetSecondaryIndividualAllocID added in v0.4.0

func (m NoAllocs) GetSecondaryIndividualAllocID() (v string, err quickfix.MessageRejectError)

GetSecondaryIndividualAllocID gets SecondaryIndividualAllocID, Tag 989.

func (NoAllocs) HasAllocAccount added in v0.4.0

func (m NoAllocs) HasAllocAccount() bool

HasAllocAccount returns true if AllocAccount is present, Tag 79.

func (NoAllocs) HasAllocAcctIDSource added in v0.4.0

func (m NoAllocs) HasAllocAcctIDSource() bool

HasAllocAcctIDSource returns true if AllocAcctIDSource is present, Tag 661.

func (NoAllocs) HasAllocCustomerCapacity added in v0.4.0

func (m NoAllocs) HasAllocCustomerCapacity() bool

HasAllocCustomerCapacity returns true if AllocCustomerCapacity is present, Tag 993.

func (NoAllocs) HasAllocPositionEffect added in v0.4.0

func (m NoAllocs) HasAllocPositionEffect() bool

HasAllocPositionEffect returns true if AllocPositionEffect is present, Tag 1047.

func (NoAllocs) HasAllocPrice added in v0.4.0

func (m NoAllocs) HasAllocPrice() bool

HasAllocPrice returns true if AllocPrice is present, Tag 366.

func (NoAllocs) HasAllocQty added in v0.4.0

func (m NoAllocs) HasAllocQty() bool

HasAllocQty returns true if AllocQty is present, Tag 80.

func (NoAllocs) HasAllocText added in v0.4.0

func (m NoAllocs) HasAllocText() bool

HasAllocText returns true if AllocText is present, Tag 161.

func (NoAllocs) HasEncodedAllocText added in v0.4.0

func (m NoAllocs) HasEncodedAllocText() bool

HasEncodedAllocText returns true if EncodedAllocText is present, Tag 361.

func (NoAllocs) HasEncodedAllocTextLen added in v0.4.0

func (m NoAllocs) HasEncodedAllocTextLen() bool

HasEncodedAllocTextLen returns true if EncodedAllocTextLen is present, Tag 360.

func (NoAllocs) HasIndividualAllocID added in v0.4.0

func (m NoAllocs) HasIndividualAllocID() bool

HasIndividualAllocID returns true if IndividualAllocID is present, Tag 467.

func (NoAllocs) HasIndividualAllocRejCode added in v0.4.0

func (m NoAllocs) HasIndividualAllocRejCode() bool

HasIndividualAllocRejCode returns true if IndividualAllocRejCode is present, Tag 776.

func (NoAllocs) HasIndividualAllocType added in v0.4.0

func (m NoAllocs) HasIndividualAllocType() bool

HasIndividualAllocType returns true if IndividualAllocType is present, Tag 992.

func (NoAllocs) HasNoNestedPartyIDs added in v0.4.0

func (m NoAllocs) HasNoNestedPartyIDs() bool

HasNoNestedPartyIDs returns true if NoNestedPartyIDs is present, Tag 539.

func (NoAllocs) HasSecondaryIndividualAllocID added in v0.4.0

func (m NoAllocs) HasSecondaryIndividualAllocID() bool

HasSecondaryIndividualAllocID returns true if SecondaryIndividualAllocID is present, Tag 989.

func (NoAllocs) SetAllocAccount added in v0.4.0

func (m NoAllocs) SetAllocAccount(v string)

SetAllocAccount sets AllocAccount, Tag 79.

func (NoAllocs) SetAllocAcctIDSource added in v0.4.0

func (m NoAllocs) SetAllocAcctIDSource(v int)

SetAllocAcctIDSource sets AllocAcctIDSource, Tag 661.

func (NoAllocs) SetAllocCustomerCapacity added in v0.4.0

func (m NoAllocs) SetAllocCustomerCapacity(v string)

SetAllocCustomerCapacity sets AllocCustomerCapacity, Tag 993.

func (NoAllocs) SetAllocPositionEffect added in v0.4.0

func (m NoAllocs) SetAllocPositionEffect(v enum.AllocPositionEffect)

SetAllocPositionEffect sets AllocPositionEffect, Tag 1047.

func (NoAllocs) SetAllocPrice added in v0.4.0

func (m NoAllocs) SetAllocPrice(value decimal.Decimal, scale int32)

SetAllocPrice sets AllocPrice, Tag 366.

func (NoAllocs) SetAllocQty added in v0.4.0

func (m NoAllocs) SetAllocQty(value decimal.Decimal, scale int32)

SetAllocQty sets AllocQty, Tag 80.

func (NoAllocs) SetAllocText added in v0.4.0

func (m NoAllocs) SetAllocText(v string)

SetAllocText sets AllocText, Tag 161.

func (NoAllocs) SetEncodedAllocText added in v0.4.0

func (m NoAllocs) SetEncodedAllocText(v string)

SetEncodedAllocText sets EncodedAllocText, Tag 361.

func (NoAllocs) SetEncodedAllocTextLen added in v0.4.0

func (m NoAllocs) SetEncodedAllocTextLen(v int)

SetEncodedAllocTextLen sets EncodedAllocTextLen, Tag 360.

func (NoAllocs) SetIndividualAllocID added in v0.4.0

func (m NoAllocs) SetIndividualAllocID(v string)

SetIndividualAllocID sets IndividualAllocID, Tag 467.

func (NoAllocs) SetIndividualAllocRejCode added in v0.4.0

func (m NoAllocs) SetIndividualAllocRejCode(v int)

SetIndividualAllocRejCode sets IndividualAllocRejCode, Tag 776.

func (NoAllocs) SetIndividualAllocType added in v0.4.0

func (m NoAllocs) SetIndividualAllocType(v enum.IndividualAllocType)

SetIndividualAllocType sets IndividualAllocType, Tag 992.

func (NoAllocs) SetNoNestedPartyIDs added in v0.4.0

func (m NoAllocs) SetNoNestedPartyIDs(f NoNestedPartyIDsRepeatingGroup)

SetNoNestedPartyIDs sets NoNestedPartyIDs, Tag 539.

func (NoAllocs) SetSecondaryIndividualAllocID added in v0.4.0

func (m NoAllocs) SetSecondaryIndividualAllocID(v string)

SetSecondaryIndividualAllocID sets SecondaryIndividualAllocID, Tag 989.

type NoAllocsRepeatingGroup added in v0.4.0

type NoAllocsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoAllocsRepeatingGroup is a repeating group, Tag 78.

func NewNoAllocsRepeatingGroup added in v0.4.0

func NewNoAllocsRepeatingGroup() NoAllocsRepeatingGroup

NewNoAllocsRepeatingGroup returns an initialized, NoAllocsRepeatingGroup.

func (NoAllocsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoAllocs to this group.

func (NoAllocsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoAllocs in the NoAllocsRepeatinGroup.

type NoNestedPartyIDs added in v0.4.0

type NoNestedPartyIDs struct {
	*quickfix.Group
}

NoNestedPartyIDs is a repeating group element, Tag 539.

func (NoNestedPartyIDs) GetNestedPartyID added in v0.4.0

func (m NoNestedPartyIDs) GetNestedPartyID() (v string, err quickfix.MessageRejectError)

GetNestedPartyID gets NestedPartyID, Tag 524.

func (NoNestedPartyIDs) GetNestedPartyIDSource added in v0.4.0

func (m NoNestedPartyIDs) GetNestedPartyIDSource() (v string, err quickfix.MessageRejectError)

GetNestedPartyIDSource gets NestedPartyIDSource, Tag 525.

func (NoNestedPartyIDs) GetNestedPartyRole added in v0.4.0

func (m NoNestedPartyIDs) GetNestedPartyRole() (v int, err quickfix.MessageRejectError)

GetNestedPartyRole gets NestedPartyRole, Tag 538.

func (NoNestedPartyIDs) GetNoNestedPartySubIDs added in v0.4.0

GetNoNestedPartySubIDs gets NoNestedPartySubIDs, Tag 804.

func (NoNestedPartyIDs) HasNestedPartyID added in v0.4.0

func (m NoNestedPartyIDs) HasNestedPartyID() bool

HasNestedPartyID returns true if NestedPartyID is present, Tag 524.

func (NoNestedPartyIDs) HasNestedPartyIDSource added in v0.4.0

func (m NoNestedPartyIDs) HasNestedPartyIDSource() bool

HasNestedPartyIDSource returns true if NestedPartyIDSource is present, Tag 525.

func (NoNestedPartyIDs) HasNestedPartyRole added in v0.4.0

func (m NoNestedPartyIDs) HasNestedPartyRole() bool

HasNestedPartyRole returns true if NestedPartyRole is present, Tag 538.

func (NoNestedPartyIDs) HasNoNestedPartySubIDs added in v0.4.0

func (m NoNestedPartyIDs) HasNoNestedPartySubIDs() bool

HasNoNestedPartySubIDs returns true if NoNestedPartySubIDs is present, Tag 804.

func (NoNestedPartyIDs) SetNestedPartyID added in v0.4.0

func (m NoNestedPartyIDs) SetNestedPartyID(v string)

SetNestedPartyID sets NestedPartyID, Tag 524.

func (NoNestedPartyIDs) SetNestedPartyIDSource added in v0.4.0

func (m NoNestedPartyIDs) SetNestedPartyIDSource(v string)

SetNestedPartyIDSource sets NestedPartyIDSource, Tag 525.

func (NoNestedPartyIDs) SetNestedPartyRole added in v0.4.0

func (m NoNestedPartyIDs) SetNestedPartyRole(v int)

SetNestedPartyRole sets NestedPartyRole, Tag 538.

func (NoNestedPartyIDs) SetNoNestedPartySubIDs added in v0.4.0

func (m NoNestedPartyIDs) SetNoNestedPartySubIDs(f NoNestedPartySubIDsRepeatingGroup)

SetNoNestedPartySubIDs sets NoNestedPartySubIDs, Tag 804.

type NoNestedPartyIDsRepeatingGroup added in v0.4.0

type NoNestedPartyIDsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoNestedPartyIDsRepeatingGroup is a repeating group, Tag 539.

func NewNoNestedPartyIDsRepeatingGroup added in v0.4.0

func NewNoNestedPartyIDsRepeatingGroup() NoNestedPartyIDsRepeatingGroup

NewNoNestedPartyIDsRepeatingGroup returns an initialized, NoNestedPartyIDsRepeatingGroup.

func (NoNestedPartyIDsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoNestedPartyIDs to this group.

func (NoNestedPartyIDsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoNestedPartyIDs in the NoNestedPartyIDsRepeatinGroup.

type NoNestedPartySubIDs added in v0.4.0

type NoNestedPartySubIDs struct {
	*quickfix.Group
}

NoNestedPartySubIDs is a repeating group element, Tag 804.

func (NoNestedPartySubIDs) GetNestedPartySubID added in v0.4.0

func (m NoNestedPartySubIDs) GetNestedPartySubID() (v string, err quickfix.MessageRejectError)

GetNestedPartySubID gets NestedPartySubID, Tag 545.

func (NoNestedPartySubIDs) GetNestedPartySubIDType added in v0.4.0

func (m NoNestedPartySubIDs) GetNestedPartySubIDType() (v int, err quickfix.MessageRejectError)

GetNestedPartySubIDType gets NestedPartySubIDType, Tag 805.

func (NoNestedPartySubIDs) HasNestedPartySubID added in v0.4.0

func (m NoNestedPartySubIDs) HasNestedPartySubID() bool

HasNestedPartySubID returns true if NestedPartySubID is present, Tag 545.

func (NoNestedPartySubIDs) HasNestedPartySubIDType added in v0.4.0

func (m NoNestedPartySubIDs) HasNestedPartySubIDType() bool

HasNestedPartySubIDType returns true if NestedPartySubIDType is present, Tag 805.

func (NoNestedPartySubIDs) SetNestedPartySubID added in v0.4.0

func (m NoNestedPartySubIDs) SetNestedPartySubID(v string)

SetNestedPartySubID sets NestedPartySubID, Tag 545.

func (NoNestedPartySubIDs) SetNestedPartySubIDType added in v0.4.0

func (m NoNestedPartySubIDs) SetNestedPartySubIDType(v int)

SetNestedPartySubIDType sets NestedPartySubIDType, Tag 805.

type NoNestedPartySubIDsRepeatingGroup added in v0.4.0

type NoNestedPartySubIDsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoNestedPartySubIDsRepeatingGroup is a repeating group, Tag 804.

func NewNoNestedPartySubIDsRepeatingGroup added in v0.4.0

func NewNoNestedPartySubIDsRepeatingGroup() NoNestedPartySubIDsRepeatingGroup

NewNoNestedPartySubIDsRepeatingGroup returns an initialized, NoNestedPartySubIDsRepeatingGroup.

func (NoNestedPartySubIDsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoNestedPartySubIDs to this group.

func (NoNestedPartySubIDsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoNestedPartySubIDs in the NoNestedPartySubIDsRepeatinGroup.

type NoPartyIDs added in v0.4.0

type NoPartyIDs struct {
	*quickfix.Group
}

NoPartyIDs is a repeating group element, Tag 453.

func (NoPartyIDs) GetNoPartySubIDs added in v0.4.0

GetNoPartySubIDs gets NoPartySubIDs, Tag 802.

func (NoPartyIDs) GetPartyID added in v0.4.0

func (m NoPartyIDs) GetPartyID() (v string, err quickfix.MessageRejectError)

GetPartyID gets PartyID, Tag 448.

func (NoPartyIDs) GetPartyIDSource added in v0.4.0

func (m NoPartyIDs) GetPartyIDSource() (v enum.PartyIDSource, err quickfix.MessageRejectError)

GetPartyIDSource gets PartyIDSource, Tag 447.

func (NoPartyIDs) GetPartyRole added in v0.4.0

func (m NoPartyIDs) GetPartyRole() (v enum.PartyRole, err quickfix.MessageRejectError)

GetPartyRole gets PartyRole, Tag 452.

func (NoPartyIDs) HasNoPartySubIDs added in v0.4.0

func (m NoPartyIDs) HasNoPartySubIDs() bool

HasNoPartySubIDs returns true if NoPartySubIDs is present, Tag 802.

func (NoPartyIDs) HasPartyID added in v0.4.0

func (m NoPartyIDs) HasPartyID() bool

HasPartyID returns true if PartyID is present, Tag 448.

func (NoPartyIDs) HasPartyIDSource added in v0.4.0

func (m NoPartyIDs) HasPartyIDSource() bool

HasPartyIDSource returns true if PartyIDSource is present, Tag 447.

func (NoPartyIDs) HasPartyRole added in v0.4.0

func (m NoPartyIDs) HasPartyRole() bool

HasPartyRole returns true if PartyRole is present, Tag 452.

func (NoPartyIDs) SetNoPartySubIDs added in v0.4.0

func (m NoPartyIDs) SetNoPartySubIDs(f NoPartySubIDsRepeatingGroup)

SetNoPartySubIDs sets NoPartySubIDs, Tag 802.

func (NoPartyIDs) SetPartyID added in v0.4.0

func (m NoPartyIDs) SetPartyID(v string)

SetPartyID sets PartyID, Tag 448.

func (NoPartyIDs) SetPartyIDSource added in v0.4.0

func (m NoPartyIDs) SetPartyIDSource(v enum.PartyIDSource)

SetPartyIDSource sets PartyIDSource, Tag 447.

func (NoPartyIDs) SetPartyRole added in v0.4.0

func (m NoPartyIDs) SetPartyRole(v enum.PartyRole)

SetPartyRole sets PartyRole, Tag 452.

type NoPartyIDsRepeatingGroup added in v0.4.0

type NoPartyIDsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoPartyIDsRepeatingGroup is a repeating group, Tag 453.

func NewNoPartyIDsRepeatingGroup added in v0.4.0

func NewNoPartyIDsRepeatingGroup() NoPartyIDsRepeatingGroup

NewNoPartyIDsRepeatingGroup returns an initialized, NoPartyIDsRepeatingGroup.

func (NoPartyIDsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoPartyIDs to this group.

func (NoPartyIDsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoPartyIDs in the NoPartyIDsRepeatinGroup.

type NoPartySubIDs added in v0.4.0

type NoPartySubIDs struct {
	*quickfix.Group
}

NoPartySubIDs is a repeating group element, Tag 802.

func (NoPartySubIDs) GetPartySubID added in v0.4.0

func (m NoPartySubIDs) GetPartySubID() (v string, err quickfix.MessageRejectError)

GetPartySubID gets PartySubID, Tag 523.

func (NoPartySubIDs) GetPartySubIDType added in v0.4.0

func (m NoPartySubIDs) GetPartySubIDType() (v enum.PartySubIDType, err quickfix.MessageRejectError)

GetPartySubIDType gets PartySubIDType, Tag 803.

func (NoPartySubIDs) HasPartySubID added in v0.4.0

func (m NoPartySubIDs) HasPartySubID() bool

HasPartySubID returns true if PartySubID is present, Tag 523.

func (NoPartySubIDs) HasPartySubIDType added in v0.4.0

func (m NoPartySubIDs) HasPartySubIDType() bool

HasPartySubIDType returns true if PartySubIDType is present, Tag 803.

func (NoPartySubIDs) SetPartySubID added in v0.4.0

func (m NoPartySubIDs) SetPartySubID(v string)

SetPartySubID sets PartySubID, Tag 523.

func (NoPartySubIDs) SetPartySubIDType added in v0.4.0

func (m NoPartySubIDs) SetPartySubIDType(v enum.PartySubIDType)

SetPartySubIDType sets PartySubIDType, Tag 803.

type NoPartySubIDsRepeatingGroup added in v0.4.0

type NoPartySubIDsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoPartySubIDsRepeatingGroup is a repeating group, Tag 802.

func NewNoPartySubIDsRepeatingGroup added in v0.4.0

func NewNoPartySubIDsRepeatingGroup() NoPartySubIDsRepeatingGroup

NewNoPartySubIDsRepeatingGroup returns an initialized, NoPartySubIDsRepeatingGroup.

func (NoPartySubIDsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoPartySubIDs to this group.

func (NoPartySubIDsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoPartySubIDs in the NoPartySubIDsRepeatinGroup.

type RouteOut

A RouteOut is the callback type that should be implemented for routing Message.

Jump to