applicationmessagerequestack

package
v0.6.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2022 License: Apache-1.1 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Route

func Route(router RouteOut) (string, string, quickfix.MessageRoute)

Route returns the beginstring, message type, and MessageRoute for this Message type.

Types

type ApplicationMessageRequestAck added in v0.4.0

type ApplicationMessageRequestAck struct {
	fixt11.Header
	*quickfix.Body
	fixt11.Trailer
	Message *quickfix.Message
}

ApplicationMessageRequestAck is the fix50sp2 ApplicationMessageRequestAck type, MsgType = BX.

func FromMessage added in v0.4.0

FromMessage creates a ApplicationMessageRequestAck from a quickfix.Message instance.

func New added in v0.2.0

New returns a ApplicationMessageRequestAck initialized with the required fields for ApplicationMessageRequestAck.

func (ApplicationMessageRequestAck) GetApplReqID added in v0.4.0

GetApplReqID gets ApplReqID, Tag 1346.

func (ApplicationMessageRequestAck) GetApplReqType added in v0.4.0

GetApplReqType gets ApplReqType, Tag 1347.

func (ApplicationMessageRequestAck) GetApplResponseID added in v0.4.0

func (m ApplicationMessageRequestAck) GetApplResponseID() (v string, err quickfix.MessageRejectError)

GetApplResponseID gets ApplResponseID, Tag 1353.

func (ApplicationMessageRequestAck) GetApplResponseType added in v0.4.0

GetApplResponseType gets ApplResponseType, Tag 1348.

func (ApplicationMessageRequestAck) GetApplTotalMessageCount added in v0.4.0

func (m ApplicationMessageRequestAck) GetApplTotalMessageCount() (v int, err quickfix.MessageRejectError)

GetApplTotalMessageCount gets ApplTotalMessageCount, Tag 1349.

func (ApplicationMessageRequestAck) GetEncodedText added in v0.4.0

func (m ApplicationMessageRequestAck) GetEncodedText() (v string, err quickfix.MessageRejectError)

GetEncodedText gets EncodedText, Tag 355.

func (ApplicationMessageRequestAck) GetEncodedTextLen added in v0.4.0

func (m ApplicationMessageRequestAck) GetEncodedTextLen() (v int, err quickfix.MessageRejectError)

GetEncodedTextLen gets EncodedTextLen, Tag 354.

func (ApplicationMessageRequestAck) GetNoApplIDs added in v0.4.0

GetNoApplIDs gets NoApplIDs, Tag 1351.

func (ApplicationMessageRequestAck) GetNoPartyIDs added in v0.4.0

GetNoPartyIDs gets NoPartyIDs, Tag 453.

func (ApplicationMessageRequestAck) GetText added in v0.4.0

GetText gets Text, Tag 58.

func (ApplicationMessageRequestAck) HasApplReqID added in v0.4.0

func (m ApplicationMessageRequestAck) HasApplReqID() bool

HasApplReqID returns true if ApplReqID is present, Tag 1346.

func (ApplicationMessageRequestAck) HasApplReqType added in v0.4.0

func (m ApplicationMessageRequestAck) HasApplReqType() bool

HasApplReqType returns true if ApplReqType is present, Tag 1347.

func (ApplicationMessageRequestAck) HasApplResponseID added in v0.4.0

func (m ApplicationMessageRequestAck) HasApplResponseID() bool

HasApplResponseID returns true if ApplResponseID is present, Tag 1353.

func (ApplicationMessageRequestAck) HasApplResponseType added in v0.4.0

func (m ApplicationMessageRequestAck) HasApplResponseType() bool

HasApplResponseType returns true if ApplResponseType is present, Tag 1348.

func (ApplicationMessageRequestAck) HasApplTotalMessageCount added in v0.4.0

func (m ApplicationMessageRequestAck) HasApplTotalMessageCount() bool

HasApplTotalMessageCount returns true if ApplTotalMessageCount is present, Tag 1349.

func (ApplicationMessageRequestAck) HasEncodedText added in v0.4.0

func (m ApplicationMessageRequestAck) HasEncodedText() bool

HasEncodedText returns true if EncodedText is present, Tag 355.

func (ApplicationMessageRequestAck) HasEncodedTextLen added in v0.4.0

func (m ApplicationMessageRequestAck) HasEncodedTextLen() bool

HasEncodedTextLen returns true if EncodedTextLen is present, Tag 354.

func (ApplicationMessageRequestAck) HasNoApplIDs added in v0.4.0

func (m ApplicationMessageRequestAck) HasNoApplIDs() bool

HasNoApplIDs returns true if NoApplIDs is present, Tag 1351.

func (ApplicationMessageRequestAck) HasNoPartyIDs added in v0.4.0

func (m ApplicationMessageRequestAck) HasNoPartyIDs() bool

HasNoPartyIDs returns true if NoPartyIDs is present, Tag 453.

func (ApplicationMessageRequestAck) HasText added in v0.4.0

func (m ApplicationMessageRequestAck) HasText() bool

HasText returns true if Text is present, Tag 58.

func (ApplicationMessageRequestAck) SetApplReqID added in v0.4.0

func (m ApplicationMessageRequestAck) SetApplReqID(v string)

SetApplReqID sets ApplReqID, Tag 1346.

func (ApplicationMessageRequestAck) SetApplReqType added in v0.4.0

func (m ApplicationMessageRequestAck) SetApplReqType(v enum.ApplReqType)

SetApplReqType sets ApplReqType, Tag 1347.

func (ApplicationMessageRequestAck) SetApplResponseID added in v0.4.0

func (m ApplicationMessageRequestAck) SetApplResponseID(v string)

SetApplResponseID sets ApplResponseID, Tag 1353.

func (ApplicationMessageRequestAck) SetApplResponseType added in v0.4.0

func (m ApplicationMessageRequestAck) SetApplResponseType(v enum.ApplResponseType)

SetApplResponseType sets ApplResponseType, Tag 1348.

func (ApplicationMessageRequestAck) SetApplTotalMessageCount added in v0.4.0

func (m ApplicationMessageRequestAck) SetApplTotalMessageCount(v int)

SetApplTotalMessageCount sets ApplTotalMessageCount, Tag 1349.

func (ApplicationMessageRequestAck) SetEncodedText added in v0.4.0

func (m ApplicationMessageRequestAck) SetEncodedText(v string)

SetEncodedText sets EncodedText, Tag 355.

func (ApplicationMessageRequestAck) SetEncodedTextLen added in v0.4.0

func (m ApplicationMessageRequestAck) SetEncodedTextLen(v int)

SetEncodedTextLen sets EncodedTextLen, Tag 354.

func (ApplicationMessageRequestAck) SetNoApplIDs added in v0.4.0

SetNoApplIDs sets NoApplIDs, Tag 1351.

func (ApplicationMessageRequestAck) SetNoPartyIDs added in v0.4.0

SetNoPartyIDs sets NoPartyIDs, Tag 453.

func (ApplicationMessageRequestAck) SetText added in v0.4.0

func (m ApplicationMessageRequestAck) SetText(v string)

SetText sets Text, Tag 58.

func (ApplicationMessageRequestAck) ToMessage added in v0.4.0

ToMessage returns a quickfix.Message instance.

type NoApplIDs added in v0.4.0

type NoApplIDs struct {
	*quickfix.Group
}

NoApplIDs is a repeating group element, Tag 1351.

func (NoApplIDs) GetApplBegSeqNum added in v0.4.0

func (m NoApplIDs) GetApplBegSeqNum() (v int, err quickfix.MessageRejectError)

GetApplBegSeqNum gets ApplBegSeqNum, Tag 1182.

func (NoApplIDs) GetApplEndSeqNum added in v0.4.0

func (m NoApplIDs) GetApplEndSeqNum() (v int, err quickfix.MessageRejectError)

GetApplEndSeqNum gets ApplEndSeqNum, Tag 1183.

func (NoApplIDs) GetApplResponseError added in v0.4.0

func (m NoApplIDs) GetApplResponseError() (v enum.ApplResponseError, err quickfix.MessageRejectError)

GetApplResponseError gets ApplResponseError, Tag 1354.

func (NoApplIDs) GetNoNestedPartyIDs added in v0.4.0

GetNoNestedPartyIDs gets NoNestedPartyIDs, Tag 539.

func (NoApplIDs) GetRefApplID added in v0.4.0

func (m NoApplIDs) GetRefApplID() (v string, err quickfix.MessageRejectError)

GetRefApplID gets RefApplID, Tag 1355.

func (NoApplIDs) GetRefApplLastSeqNum added in v0.4.0

func (m NoApplIDs) GetRefApplLastSeqNum() (v int, err quickfix.MessageRejectError)

GetRefApplLastSeqNum gets RefApplLastSeqNum, Tag 1357.

func (NoApplIDs) GetRefApplReqID added in v0.4.0

func (m NoApplIDs) GetRefApplReqID() (v string, err quickfix.MessageRejectError)

GetRefApplReqID gets RefApplReqID, Tag 1433.

func (NoApplIDs) HasApplBegSeqNum added in v0.4.0

func (m NoApplIDs) HasApplBegSeqNum() bool

HasApplBegSeqNum returns true if ApplBegSeqNum is present, Tag 1182.

func (NoApplIDs) HasApplEndSeqNum added in v0.4.0

func (m NoApplIDs) HasApplEndSeqNum() bool

HasApplEndSeqNum returns true if ApplEndSeqNum is present, Tag 1183.

func (NoApplIDs) HasApplResponseError added in v0.4.0

func (m NoApplIDs) HasApplResponseError() bool

HasApplResponseError returns true if ApplResponseError is present, Tag 1354.

func (NoApplIDs) HasNoNestedPartyIDs added in v0.4.0

func (m NoApplIDs) HasNoNestedPartyIDs() bool

HasNoNestedPartyIDs returns true if NoNestedPartyIDs is present, Tag 539.

func (NoApplIDs) HasRefApplID added in v0.4.0

func (m NoApplIDs) HasRefApplID() bool

HasRefApplID returns true if RefApplID is present, Tag 1355.

func (NoApplIDs) HasRefApplLastSeqNum added in v0.4.0

func (m NoApplIDs) HasRefApplLastSeqNum() bool

HasRefApplLastSeqNum returns true if RefApplLastSeqNum is present, Tag 1357.

func (NoApplIDs) HasRefApplReqID added in v0.4.0

func (m NoApplIDs) HasRefApplReqID() bool

HasRefApplReqID returns true if RefApplReqID is present, Tag 1433.

func (NoApplIDs) SetApplBegSeqNum added in v0.4.0

func (m NoApplIDs) SetApplBegSeqNum(v int)

SetApplBegSeqNum sets ApplBegSeqNum, Tag 1182.

func (NoApplIDs) SetApplEndSeqNum added in v0.4.0

func (m NoApplIDs) SetApplEndSeqNum(v int)

SetApplEndSeqNum sets ApplEndSeqNum, Tag 1183.

func (NoApplIDs) SetApplResponseError added in v0.4.0

func (m NoApplIDs) SetApplResponseError(v enum.ApplResponseError)

SetApplResponseError sets ApplResponseError, Tag 1354.

func (NoApplIDs) SetNoNestedPartyIDs added in v0.4.0

func (m NoApplIDs) SetNoNestedPartyIDs(f NoNestedPartyIDsRepeatingGroup)

SetNoNestedPartyIDs sets NoNestedPartyIDs, Tag 539.

func (NoApplIDs) SetRefApplID added in v0.4.0

func (m NoApplIDs) SetRefApplID(v string)

SetRefApplID sets RefApplID, Tag 1355.

func (NoApplIDs) SetRefApplLastSeqNum added in v0.4.0

func (m NoApplIDs) SetRefApplLastSeqNum(v int)

SetRefApplLastSeqNum sets RefApplLastSeqNum, Tag 1357.

func (NoApplIDs) SetRefApplReqID added in v0.4.0

func (m NoApplIDs) SetRefApplReqID(v string)

SetRefApplReqID sets RefApplReqID, Tag 1433.

type NoApplIDsRepeatingGroup added in v0.4.0

type NoApplIDsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoApplIDsRepeatingGroup is a repeating group, Tag 1351.

func NewNoApplIDsRepeatingGroup added in v0.4.0

func NewNoApplIDsRepeatingGroup() NoApplIDsRepeatingGroup

NewNoApplIDsRepeatingGroup returns an initialized, NoApplIDsRepeatingGroup.

func (NoApplIDsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoApplIDs to this group.

func (NoApplIDsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoApplIDs in the NoApplIDsRepeatinGroup.

type NoNestedPartyIDs added in v0.4.0

type NoNestedPartyIDs struct {
	*quickfix.Group
}

NoNestedPartyIDs is a repeating group element, Tag 539.

func (NoNestedPartyIDs) GetNestedPartyID added in v0.4.0

func (m NoNestedPartyIDs) GetNestedPartyID() (v string, err quickfix.MessageRejectError)

GetNestedPartyID gets NestedPartyID, Tag 524.

func (NoNestedPartyIDs) GetNestedPartyIDSource added in v0.4.0

func (m NoNestedPartyIDs) GetNestedPartyIDSource() (v string, err quickfix.MessageRejectError)

GetNestedPartyIDSource gets NestedPartyIDSource, Tag 525.

func (NoNestedPartyIDs) GetNestedPartyRole added in v0.4.0

func (m NoNestedPartyIDs) GetNestedPartyRole() (v int, err quickfix.MessageRejectError)

GetNestedPartyRole gets NestedPartyRole, Tag 538.

func (NoNestedPartyIDs) GetNoNestedPartySubIDs added in v0.4.0

GetNoNestedPartySubIDs gets NoNestedPartySubIDs, Tag 804.

func (NoNestedPartyIDs) HasNestedPartyID added in v0.4.0

func (m NoNestedPartyIDs) HasNestedPartyID() bool

HasNestedPartyID returns true if NestedPartyID is present, Tag 524.

func (NoNestedPartyIDs) HasNestedPartyIDSource added in v0.4.0

func (m NoNestedPartyIDs) HasNestedPartyIDSource() bool

HasNestedPartyIDSource returns true if NestedPartyIDSource is present, Tag 525.

func (NoNestedPartyIDs) HasNestedPartyRole added in v0.4.0

func (m NoNestedPartyIDs) HasNestedPartyRole() bool

HasNestedPartyRole returns true if NestedPartyRole is present, Tag 538.

func (NoNestedPartyIDs) HasNoNestedPartySubIDs added in v0.4.0

func (m NoNestedPartyIDs) HasNoNestedPartySubIDs() bool

HasNoNestedPartySubIDs returns true if NoNestedPartySubIDs is present, Tag 804.

func (NoNestedPartyIDs) SetNestedPartyID added in v0.4.0

func (m NoNestedPartyIDs) SetNestedPartyID(v string)

SetNestedPartyID sets NestedPartyID, Tag 524.

func (NoNestedPartyIDs) SetNestedPartyIDSource added in v0.4.0

func (m NoNestedPartyIDs) SetNestedPartyIDSource(v string)

SetNestedPartyIDSource sets NestedPartyIDSource, Tag 525.

func (NoNestedPartyIDs) SetNestedPartyRole added in v0.4.0

func (m NoNestedPartyIDs) SetNestedPartyRole(v int)

SetNestedPartyRole sets NestedPartyRole, Tag 538.

func (NoNestedPartyIDs) SetNoNestedPartySubIDs added in v0.4.0

func (m NoNestedPartyIDs) SetNoNestedPartySubIDs(f NoNestedPartySubIDsRepeatingGroup)

SetNoNestedPartySubIDs sets NoNestedPartySubIDs, Tag 804.

type NoNestedPartyIDsRepeatingGroup added in v0.4.0

type NoNestedPartyIDsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoNestedPartyIDsRepeatingGroup is a repeating group, Tag 539.

func NewNoNestedPartyIDsRepeatingGroup added in v0.4.0

func NewNoNestedPartyIDsRepeatingGroup() NoNestedPartyIDsRepeatingGroup

NewNoNestedPartyIDsRepeatingGroup returns an initialized, NoNestedPartyIDsRepeatingGroup.

func (NoNestedPartyIDsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoNestedPartyIDs to this group.

func (NoNestedPartyIDsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoNestedPartyIDs in the NoNestedPartyIDsRepeatinGroup.

type NoNestedPartySubIDs added in v0.4.0

type NoNestedPartySubIDs struct {
	*quickfix.Group
}

NoNestedPartySubIDs is a repeating group element, Tag 804.

func (NoNestedPartySubIDs) GetNestedPartySubID added in v0.4.0

func (m NoNestedPartySubIDs) GetNestedPartySubID() (v string, err quickfix.MessageRejectError)

GetNestedPartySubID gets NestedPartySubID, Tag 545.

func (NoNestedPartySubIDs) GetNestedPartySubIDType added in v0.4.0

func (m NoNestedPartySubIDs) GetNestedPartySubIDType() (v int, err quickfix.MessageRejectError)

GetNestedPartySubIDType gets NestedPartySubIDType, Tag 805.

func (NoNestedPartySubIDs) HasNestedPartySubID added in v0.4.0

func (m NoNestedPartySubIDs) HasNestedPartySubID() bool

HasNestedPartySubID returns true if NestedPartySubID is present, Tag 545.

func (NoNestedPartySubIDs) HasNestedPartySubIDType added in v0.4.0

func (m NoNestedPartySubIDs) HasNestedPartySubIDType() bool

HasNestedPartySubIDType returns true if NestedPartySubIDType is present, Tag 805.

func (NoNestedPartySubIDs) SetNestedPartySubID added in v0.4.0

func (m NoNestedPartySubIDs) SetNestedPartySubID(v string)

SetNestedPartySubID sets NestedPartySubID, Tag 545.

func (NoNestedPartySubIDs) SetNestedPartySubIDType added in v0.4.0

func (m NoNestedPartySubIDs) SetNestedPartySubIDType(v int)

SetNestedPartySubIDType sets NestedPartySubIDType, Tag 805.

type NoNestedPartySubIDsRepeatingGroup added in v0.4.0

type NoNestedPartySubIDsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoNestedPartySubIDsRepeatingGroup is a repeating group, Tag 804.

func NewNoNestedPartySubIDsRepeatingGroup added in v0.4.0

func NewNoNestedPartySubIDsRepeatingGroup() NoNestedPartySubIDsRepeatingGroup

NewNoNestedPartySubIDsRepeatingGroup returns an initialized, NoNestedPartySubIDsRepeatingGroup.

func (NoNestedPartySubIDsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoNestedPartySubIDs to this group.

func (NoNestedPartySubIDsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoNestedPartySubIDs in the NoNestedPartySubIDsRepeatinGroup.

type NoPartyIDs added in v0.4.0

type NoPartyIDs struct {
	*quickfix.Group
}

NoPartyIDs is a repeating group element, Tag 453.

func (NoPartyIDs) GetNoPartySubIDs added in v0.4.0

GetNoPartySubIDs gets NoPartySubIDs, Tag 802.

func (NoPartyIDs) GetPartyID added in v0.4.0

func (m NoPartyIDs) GetPartyID() (v string, err quickfix.MessageRejectError)

GetPartyID gets PartyID, Tag 448.

func (NoPartyIDs) GetPartyIDSource added in v0.4.0

func (m NoPartyIDs) GetPartyIDSource() (v enum.PartyIDSource, err quickfix.MessageRejectError)

GetPartyIDSource gets PartyIDSource, Tag 447.

func (NoPartyIDs) GetPartyRole added in v0.4.0

func (m NoPartyIDs) GetPartyRole() (v enum.PartyRole, err quickfix.MessageRejectError)

GetPartyRole gets PartyRole, Tag 452.

func (NoPartyIDs) HasNoPartySubIDs added in v0.4.0

func (m NoPartyIDs) HasNoPartySubIDs() bool

HasNoPartySubIDs returns true if NoPartySubIDs is present, Tag 802.

func (NoPartyIDs) HasPartyID added in v0.4.0

func (m NoPartyIDs) HasPartyID() bool

HasPartyID returns true if PartyID is present, Tag 448.

func (NoPartyIDs) HasPartyIDSource added in v0.4.0

func (m NoPartyIDs) HasPartyIDSource() bool

HasPartyIDSource returns true if PartyIDSource is present, Tag 447.

func (NoPartyIDs) HasPartyRole added in v0.4.0

func (m NoPartyIDs) HasPartyRole() bool

HasPartyRole returns true if PartyRole is present, Tag 452.

func (NoPartyIDs) SetNoPartySubIDs added in v0.4.0

func (m NoPartyIDs) SetNoPartySubIDs(f NoPartySubIDsRepeatingGroup)

SetNoPartySubIDs sets NoPartySubIDs, Tag 802.

func (NoPartyIDs) SetPartyID added in v0.4.0

func (m NoPartyIDs) SetPartyID(v string)

SetPartyID sets PartyID, Tag 448.

func (NoPartyIDs) SetPartyIDSource added in v0.4.0

func (m NoPartyIDs) SetPartyIDSource(v enum.PartyIDSource)

SetPartyIDSource sets PartyIDSource, Tag 447.

func (NoPartyIDs) SetPartyRole added in v0.4.0

func (m NoPartyIDs) SetPartyRole(v enum.PartyRole)

SetPartyRole sets PartyRole, Tag 452.

type NoPartyIDsRepeatingGroup added in v0.4.0

type NoPartyIDsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoPartyIDsRepeatingGroup is a repeating group, Tag 453.

func NewNoPartyIDsRepeatingGroup added in v0.4.0

func NewNoPartyIDsRepeatingGroup() NoPartyIDsRepeatingGroup

NewNoPartyIDsRepeatingGroup returns an initialized, NoPartyIDsRepeatingGroup.

func (NoPartyIDsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoPartyIDs to this group.

func (NoPartyIDsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoPartyIDs in the NoPartyIDsRepeatinGroup.

type NoPartySubIDs added in v0.4.0

type NoPartySubIDs struct {
	*quickfix.Group
}

NoPartySubIDs is a repeating group element, Tag 802.

func (NoPartySubIDs) GetPartySubID added in v0.4.0

func (m NoPartySubIDs) GetPartySubID() (v string, err quickfix.MessageRejectError)

GetPartySubID gets PartySubID, Tag 523.

func (NoPartySubIDs) GetPartySubIDType added in v0.4.0

func (m NoPartySubIDs) GetPartySubIDType() (v enum.PartySubIDType, err quickfix.MessageRejectError)

GetPartySubIDType gets PartySubIDType, Tag 803.

func (NoPartySubIDs) HasPartySubID added in v0.4.0

func (m NoPartySubIDs) HasPartySubID() bool

HasPartySubID returns true if PartySubID is present, Tag 523.

func (NoPartySubIDs) HasPartySubIDType added in v0.4.0

func (m NoPartySubIDs) HasPartySubIDType() bool

HasPartySubIDType returns true if PartySubIDType is present, Tag 803.

func (NoPartySubIDs) SetPartySubID added in v0.4.0

func (m NoPartySubIDs) SetPartySubID(v string)

SetPartySubID sets PartySubID, Tag 523.

func (NoPartySubIDs) SetPartySubIDType added in v0.4.0

func (m NoPartySubIDs) SetPartySubIDType(v enum.PartySubIDType)

SetPartySubIDType sets PartySubIDType, Tag 803.

type NoPartySubIDsRepeatingGroup added in v0.4.0

type NoPartySubIDsRepeatingGroup struct {
	*quickfix.RepeatingGroup
}

NoPartySubIDsRepeatingGroup is a repeating group, Tag 802.

func NewNoPartySubIDsRepeatingGroup added in v0.4.0

func NewNoPartySubIDsRepeatingGroup() NoPartySubIDsRepeatingGroup

NewNoPartySubIDsRepeatingGroup returns an initialized, NoPartySubIDsRepeatingGroup.

func (NoPartySubIDsRepeatingGroup) Add added in v0.4.0

Add create and append a new NoPartySubIDs to this group.

func (NoPartySubIDsRepeatingGroup) Get added in v0.4.0

Get returns the ith NoPartySubIDs in the NoPartySubIDsRepeatinGroup.

type RouteOut

A RouteOut is the callback type that should be implemented for routing Message.

Jump to